@@ -11,7 +11,8 @@ from enum import Enum
 List  = typing.List
 Tuple = typing.Tuple
 pypi_base_url = "http://zifuture.com:1556/fs/pypi"
-version = "1.1.25"
+version = "1.1.26"
+nvbin_version = "v6.0"
 
 lean_metas = [
     {
@@ -21,13 +22,19 @@ lean_metas = [
         "tensorRT": "8.0.1.6",
         "min_driver_version_linux": "440.33",
         "min_driver_version_windows": "441.22",
-        "binary_url_linux": f"{pypi_base_url}/nvbin/v5.0/trt8cuda102cudnn8.zip",
-        "binary_linux_md5": "67fddf1f9d54f7b58a1db27a7724d792",
+        "binary_url_linux": f"{pypi_base_url}/nvbin/{nvbin_version}/trt8cuda102cudnn8.zip",
+        "binary_linux_md5": "6f53945d3e9463854bcda1fb0cd59462",
         "syslib_linux_md5": "08f8c76348d3a0a7a076f9f6f5a928a3",
         "syslib_windows_md5": None,
         "binary_url_windows": None,
         "binary_windows_md5": None,
         "pycs": [
+            {
+                "name": "py36trt8cuda102cudnn8",
+                "python": "3.6",
+                "lean": "trt8cuda102cudnn8",
+                "binary_url_prefix": f"{pypi_base_url}/{version}/py36-trt8-cuda10.2-cudnn8",
+            },
             {
                 "name": "py37trt8cuda102cudnn8",
                 "python": "3.7",
@@ -55,13 +62,19 @@ lean_metas = [
         "tensorRT": "8.0.3.4",
         "min_driver_version_linux": "460.27.04",
         "min_driver_version_windows": "460.89",
-        "binary_url_linux": f"{pypi_base_url}/nvbin/v5.0/trt8cuda112cudnn8.zip",
-        "binary_linux_md5": "94abf8c8851ececf8d8eb5b6ff281299",
+        "binary_url_linux": f"{pypi_base_url}/nvbin/{nvbin_version}/trt8cuda112cudnn8.zip",
+        "binary_linux_md5": "bd13ef8c39e6a4d182e562e1c204bf1c",
         "syslib_linux_md5": "08f8c76348d3a0a7a076f9f6f5a928a3",
         "syslib_windows_md5": None,
         "binary_url_windows": None,
         "binary_windows_md5": None,
         "pycs": [
+            {
+                "name": "py36trt8cuda112cudnn8",
+                "python": "3.6",
+                "lean": "trt8cuda112cudnn8",
+                "binary_url_prefix": f"{pypi_base_url}/{version}/py36-trt8-cuda11.2-cudnn8",
+            },
             {
                 "name": "py37trt8cuda112cudnn8",
                 "python": "3.7",
@@ -81,6 +94,46 @@ lean_metas = [
                 "binary_url_prefix": f"{pypi_base_url}/{version}/py39-trt8-cuda11.2-cudnn8",
             }
         ]
+    },
+    {
+        "name": "trt8cuda115cudnn8",
+        "cuda": "11.5.2",
+        "cudnn": "8.3.2.44",
+        "tensorRT": "8.2.2.26",
+        "min_driver_version_linux": "495.29.05",
+        "min_driver_version_windows": "496.13",
+        "binary_url_linux": f"{pypi_base_url}/nvbin/{nvbin_version}/trt8cuda115cudnn8.zip",
+        "binary_linux_md5": "a8bb4a50291fabae197e5699d2433b41",
+        "syslib_linux_md5": "08f8c76348d3a0a7a076f9f6f5a928a3",
+        "syslib_windows_md5": None,
+        "binary_url_windows": None,
+        "binary_windows_md5": None,
+        "pycs": [
+            {
+                "name": "py36trt8cuda115cudnn8",
+                "python": "3.6",
+                "lean": "trt8cuda115cudnn8",
+                "binary_url_prefix": f"{pypi_base_url}/{version}/py36-trt8-cuda11.5-cudnn8",
+            },
+            {
+                "name": "py37trt8cuda115cudnn8",
+                "python": "3.7",
+                "lean": "trt8cuda115cudnn8",
+                "binary_url_prefix": f"{pypi_base_url}/{version}/py37-trt8-cuda11.5-cudnn8",
+            },
+            {
+                "name": "py38trt8cuda115cudnn8",
+                "python": "3.8",
+                "lean": "trt8cuda115cudnn8",
+                "binary_url_prefix": f"{pypi_base_url}/{version}/py38-trt8-cuda11.5-cudnn8",
+            },
+            {
+                "name": "py39trt8cuda115cudnn8",
+                "python": "3.9",
+                "lean": "trt8cuda115cudnn8",
+                "binary_url_prefix": f"{pypi_base_url}/{version}/py39-trt8-cuda11.5-cudnn8",
+            }
+        ]
     }
 ]
 
@@ -716,6 +769,9 @@ def init(cuda_version : str=None, tensorrt_version : str=None, load_lean_library
 
     global module_variables
     current_kernel_module_driver_version = get_current_driver_version()
+    if current_kernel_module_driver_version is None:
+        raise RuntimeError("无法获取驱动版本，请确认是否安装有nvidia显卡驱动，目前仅支持linux x86-64，并且配置有nvidia驱动的设备")
+
     assert current_kernel_module_driver_version is not None, "Can not fetch kernel module driver version"
 
     lean_meta = list(filter(lambda x:compare_version_a_lesseq_b(x[f"min_driver_version_{os_name}"], current_kernel_module_driver_version), lean_metas))
