@@ -84,13 +84,13 @@ def do_get_cpp_pkg(args):
     print("Done")
     return 0
 
-def do_if_exec():
-    if not (len(sys.argv) > 1 and sys.argv[1] == "exec"):
+def do_dispatch_command(cmd_name):
+    if not (len(sys.argv) > 1 and sys.argv[1] == cmd_name):
         return
 
     args = sys.argv
-    if len(args) > 2 and args[2] == "--help":
-        return
+    # if len(args) > 2 and args[2] == "--help":
+    #     return
 
     i = 2
     cuda_version = None
@@ -119,7 +119,14 @@ def do_if_exec():
             trt_args[i] = trt_args[i].replace("~/", os.path.expanduser("~") + "/")
 
     trtpy.init(cuda_version=cuda_version, tensorrt_version=trt_version)
-    cmd = trtpy.trtexec_path + " " + " ".join(trt_args)
+    if cmd_name == "exec":
+        path = trtpy.trtexec_path
+    elif cmd_name == "protoc":
+        path = os.path.join(trtpy.nv_root, "bin", "protoc")
+    else:
+        raise RuntimeError(f"Unknow cmd [{cmd_name}]")
+
+    cmd = path + " " + " ".join(trt_args)
     p = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, encoding="utf-8", errors="replace")
 
     while True:
@@ -128,7 +135,7 @@ def do_if_exec():
             break
 
         if realtime_output:
-            print(realtime_output.strip(), flush=True)
+            print(realtime_output, flush=True, end="")
     sys.exit(p.returncode)
 
 
@@ -148,6 +155,7 @@ def get_variable_template():
         variable_template.append(["CUDNN_INCLUDE", f"{trtpy.nv_root}/include/cudnn"])
         variable_template.append(["TENSORRT_INCLUDE", f"{trtpy.nv_root}/include/tensorRT"])
         variable_template.append(["PROTOBUF_INCLUDE", f"{trtpy.nv_root}/include/protobuf"])
+        variable_template.append(["PROTOC_PATH", f"{trtpy.nv_root}/bin/protoc"])
         variable_template.append(["NVLIB64", f"{trtpy.nv_root}/lib64"])
     return variable_template
 
@@ -167,6 +175,7 @@ def get_inv_variable_template():
         variable_template.append(["CUDNN_INCLUDE", f"{trtpy.nv_root}/include/cudnn"])
         variable_template.append(["TENSORRT_INCLUDE", f"{trtpy.nv_root}/include/tensorRT"])
         variable_template.append(["PROTOBUF_INCLUDE", f"{trtpy.nv_root}/include/protobuf"])
+        variable_template.append(["PROTOC_PATH", f"{trtpy.nv_root}/bin/protoc"])
         variable_template.append(["NVLIB64", f"{trtpy.nv_root}/lib64"])
 
     variable_template = sorted(variable_template, key=lambda x:len(x[1]), reverse=True)
@@ -422,7 +431,7 @@ def do_templ_search(args):
         print(f"-{i+1}. {name} [{language}] : {descript}")
     return 0
 
-def do_series_detial(args):
+def do_series_detail(args):
     
     if args.name == "" or args.name == ".":
         print_current = True
@@ -652,7 +661,8 @@ def do_invert_variable(args):
     return 0
 
 if __name__ == "__main__":
-    do_if_exec()
+    do_dispatch_command("exec")
+    do_dispatch_command("protoc")
 
     def new_parser_with_version(name, help):
         global subp
@@ -697,7 +707,7 @@ if __name__ == "__main__":
     p.add_argument("--raw", action="store_true", help="do not replace variables")
     p.add_argument("--download", action="store_true", help="ignore cache and download template")
 
-    p = subp.add_parser("series-detial", help="change series proj")
+    p = subp.add_parser("series-detail", help="change series proj")
     p.add_argument("name", type=str, default="", help="series name", nargs="?")
     p.add_argument("--download", action="store_true", help="ignore cache and download template")
 
@@ -747,7 +757,7 @@ if __name__ == "__main__":
         "list-series":   do_series_list,
         "search-series": do_series_search,
         "change-proj":   do_change_proj,
-        "series-detial": do_series_detial
+        "series-detail": do_series_detail
     }
 
     if args.cmd in cmd_funcs:
